AtomicConfig class

Configure for how you interact with the Atomic Transact SDK

Constructors

AtomicConfig({required String publicToken, String? scope, List<AtomicTask>? tasks, @Deprecated("This has been moved to 'tasks'") AtomicProductType? product, AtomicProductType? additionalProduct, @Deprecated("This has been moved to 'tasks'") AtomicDistribution? distribution, String? linkedAccount, AtomicTheme? theme, String language = 'en', AtomicDeeplink? deeplink, Map<String, String>? metadata, AtomicSearch? search, List<AtomicTransactHandoff>? handoff, AtomicExperiments? experiments, Customer? customer})

Properties

additionalProduct AtomicProductType?
The additional product to initiate.
final
customer Customer?
Customer information
final
Optionally deeplink into a specific step
final
distribution AtomicDistribution?
Optionally pass in enforced deposit settings. Enforcing deposit settings will eliminate company search results that do not support the distribution settings.
final
experiments AtomicExperiments?
Used to override feature flags
final
handoff List<AtomicTransactHandoff>?
Handoff allows views to be handled outside of Transact.
final
hashCode int
The hash code for this object.
no setterinherited
language String
Optionally change the language. Could be either 'en' for English or 'es' for Spanish. Default is 'en', unless the user's current locale is Spanish, then Spanish will be used. Default value: 'en'
final
linkedAccount String?
The linked account to use
final
metadata Map<String, String>?
Optionally pass data to Transact that will be returned to you in webhook events.
final
product AtomicProductType?
The product to initiate. Valid values include deposit, verify, switch, or present.
final
publicToken String
The public token returned during AccessToken creation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String?
The scope
final
Used to optionally enforce search queries
final
tasks List<AtomicTask>?
Defines configuration for the tasks you wish to execute as part of the task workflow.
final
theme AtomicTheme?
Optionally provide colors to customize Transact.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a JSON object representation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited