tasks property
Defines configuration for the tasks you wish to execute as part of the task workflow.
Implementation
final List<AtomicTask>? tasks;
Defines configuration for the tasks you wish to execute as part of the task workflow.
final List<AtomicTask>? tasks;