AtomicDeeplink class

Deeplink users into a specific step or app

Constructors

AtomicDeeplink.app(DeeplinkApp app)
Create a deeplink to a specific app in the Payments Hub
factory
AtomicDeeplink.step(DeeplinkStep step)
Create a deeplink to a specific step
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Returns a JSON object representation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited