AtomicDeeplinkStep enum
- Inheritance
- Available extensions
- Annotations
-
- @Deprecated('Use AtomicDeeplink.step() with DeeplinkStep instead (e.g., AtomicDeeplink.step(DeeplinkStep.loginCompany(...)))')
Values
- search_company → const AtomicDeeplinkStep
- search_payroll → const AtomicDeeplinkStep
-
This value requires companyName parameter.
- login_company → const AtomicDeeplinkStep
-
This value requires companyId parameter.
- login_payroll → const AtomicDeeplinkStep
-
This value requires companyName and connectorId.
- add_card → const AtomicDeeplinkStep
-
Add card step.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AtomicDeeplinkStep> - A constant List of the values in this enum, in order of their declaration.