canUpdate property
Allows a user to specify any amount they would like, overwriting the default amount. Defaults to false.
Implementation
final bool? canUpdate;
Allows a user to specify any amount they would like, overwriting the default amount. Defaults to false.
final bool? canUpdate;