AtomicTransactAuthStatusUpdate class
Constructors
- AtomicTransactAuthStatusUpdate({required String status, required AtomicTransactCompany company})
-
AtomicTransactAuthStatusUpdate.fromJson(Map<
Object?, Object?> json) -
factory
Properties
- company → AtomicTransactCompany
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited