DeeplinkApp class abstract

Deeplink app options for Payments Hub

Implementers

Constructors

DeeplinkApp()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

payNow({required List<String> payments, required String accountId}) DeeplinkAppPayNow
Deeplink to the Pay Now app

Constants

expenses → const DeeplinkApp
Deeplink to the Expenses app
orders → const DeeplinkApp
Deeplink to the Orders app
suggestions → const DeeplinkApp
Deeplink to the Suggestions app