DeeplinkAppPayNow class
Deeplink to the Pay Now app with associated data
- Inheritance
-
- Object
- DeeplinkApp
- DeeplinkAppPayNow
Constructors
-
DeeplinkAppPayNow({required List<
String> payments, required String accountId}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited