DeeplinkStepLoginCompany class
Deeplink to the company login step with associated data
- Inheritance
-
- Object
- DeeplinkStep
- DeeplinkStepLoginCompany
Constructors
- DeeplinkStepLoginCompany({required String companyId, String? connectorId, bool? singleSwitch})
-
const
Properties
- companyId → String
-
final
- connectorId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singleSwitch → bool?
-
final
- step → AtomicDeeplinkStep
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited