TaskApp class abstract

Task app options

Constructors

TaskApp()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

expenses → const TaskApp
Expenses app
orders → const TaskApp
Orders app
payNow → const TaskApp
Pay Now app
suggestions → const TaskApp
Suggestions app