TransactEnvironment class

Properties

apiPath → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactPath → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

custom(String transactPath, String apiPath) → TransactEnvironment
Custom environment with specified path

Constants

production → const TransactEnvironment
Production environment
sandbox → const TransactEnvironment
Sandbox environment