AtomicMethodChannel class

Inheritance

Constructors

AtomicMethodChannel()

Properties

activeTransactCount → int
Number of launches whose handlers are still registered.
no setter
channel → MethodChannel
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dismissTransact() → Future<void>
override
hideTransact() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseTransact() → Future<void>
override
presentTransact({required AtomicConfig configuration, required TransactEnvironment environment, AtomicPresentationStyleIOS? presentationStyleIOS, bool debug = false, AtomicInteractionHandler? onInteraction, AtomicDataRequestHandler? onDataRequest, AtomicAuthStatusUpdateHandler? onAuthStatusUpdate, AtomicTaskStatusUpdateHandler? onTaskStatusUpdate, AtomicLaunchHandler? onLaunch, AtomicCompletionHandler? onCompletion, AtomicCleanupHandler? onCleanup}) → Future<String>
Present the Atomic Transact SDK
override
removeTransact(String instanceId) → void
Stops delivering callbacks for the launch with instanceId.
override
resumeTransact() → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited