AtomicPlatformInterface class abstract

Inheritance
  • Object
  • PlatformInterface
  • AtomicPlatformInterface
Implementers

Constructors

AtomicPlatformInterface()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dismissTransact() → Future<void>
hideTransact() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseTransact() → Future<void>
presentTransact({required AtomicConfig configuration, required TransactEnvironment environment, AtomicPresentationStyleIOS? presentationStyleIOS, bool debug = false, AtomicInteractionHandler? onInteraction, AtomicDataRequestHandler? onDataRequest, AtomicAuthStatusUpdateHandler? onAuthStatusUpdate, AtomicTaskStatusUpdateHandler? onTaskStatusUpdate, AtomicLaunchHandler? onLaunch, AtomicCompletionHandler? onCompletion, AtomicCleanupHandler? onCleanup}) → Future<String>
Present the Atomic Transact SDK
removeTransact(String instanceId) → void
Stops delivering callbacks for the launch with instanceId.
resumeTransact() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ AtomicPlatformInterface
getter/setter pair