atomic_transact_flutter library
Classes
- Atomic
- AtomicConfig
- Configure for how you interact with the Atomic Transact SDK
- AtomicDeeplink
- Deeplink users into a specific step or app
- AtomicDistribution
- Pass in enforced deposit settings. Enforcing deposit settings will eliminate company search results that do not support the distribution settings.
- AtomicExperiments
- Override feature flags found in your Atomic Dashboard settings. This parameter can help run A/B tests on features within Transact.
- AtomicSearch
- Enforce search queries
- AtomicTask
- Defines configuration for the tasks you wish to execute as part of the task workflow.
- AtomicTheme
- Provide colors to customize Transact.
- AtomicTransactAuthStatusUpdate
- AtomicTransactBranding
- AtomicTransactCompany
- AtomicTransactDataRequest
- AtomicTransactInteraction
- AtomicTransactLogo
- AtomicTransactResponse
- Response returned when transact is closed
- AtomicTransactTaskStatusUpdate
- Customer
- Represents customer information
- DeeplinkApp
- Deeplink app options for Payments Hub
- DeeplinkAppPayNow
- Deeplink to the Pay Now app with associated data
- DeeplinkStep
- Deeplink step options
- DeeplinkStepLoginCompany
- Deeplink to the company login step with associated data
- DeeplinkStepLoginPayroll
- Deeplink to the payroll login step with associated data
- PausedTransactRef
- A reference to a paused Transact session. Call resume to present the Transact view again.
- TaskApp
- Task app options
- TransactEnvironment
Enums
- AtomicDeeplinkStep
- AtomicDistributionType
- Type of distribution
- AtomicOperationType
- The operation type to initiate
- AtomicPresentationStyleIOS
- iOS modal presentation styles
- AtomicProductType
- The product to initiate
- AtomicTransactCompletionType
- AtomicTransactError
- Reasons that transact might fail to load
- AtomicTransactHandoff
Typedefs
- AtomicAuthStatusUpdateHandler = void Function(AtomicTransactAuthStatusUpdate authStatus)
- Closure that will be called when a Transact auth status update event occurs
- AtomicCompletionHandler = void Function(AtomicTransactCompletionType type, AtomicTransactResponse? response, AtomicTransactError? error)
- Response with more information when Transact completes and dismisses.
- AtomicDataRequestHandler = void Function(AtomicTransactDataRequest request)
- Closure that will be called when a Transact data request event occurs
- AtomicInteractionHandler = void Function(AtomicTransactInteraction interaction)
- Closure that will be called when a Transact Interaction event occurs
- AtomicLaunchHandler = void Function()
- Closure that will be called when a Transact Action launch event occurs
- AtomicTaskStatusUpdateHandler = void Function(AtomicTransactTaskStatusUpdate taskStatus)
- Closure that will be called when a Transact task status update event occurs
Exceptions / Errors
- PauseTransactException
- Error thrown when pauseTransact fails