Atomic class
Constructors
- Atomic()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
close(
) → Future< void> -
hide(
) → Future< void> -
pauseTransact(
) → Future< PausedTransactRef> - Hides any currently open Transact views and returns a reference to present them again later. Call PausedTransactRef.resume to present the Transact view again. Throws PauseTransactException if no Transact is currently presented.
-
transact(
{required AtomicConfig config, TransactEnvironment environment = TransactEnvironment.production, AtomicInteractionHandler? onInteraction, AtomicDataRequestHandler? onDataRequest, AtomicAuthStatusUpdateHandler? onAuthStatusUpdate, AtomicTaskStatusUpdateHandler? onTaskStatusUpdate, AtomicLaunchHandler? onLaunch, AtomicCompletionHandler? onCompletion, AtomicPresentationStyleIOS? presentationStyleIOS, bool debug = false}) → Future< void> - Present the Atomic Transact SDK