amount property
When type is fixed, it indicates a dollar amount to be used for the distribution. When type is percent, it indicates a percentage of a paycheck. This is not required if type is total. This value cannot be updated by the user unless canUpdate is set to true.
Implementation
final num? amount;