AtomicTransactTaskStatusUpdate class
Constructors
-
AtomicTransactTaskStatusUpdate({required String taskId, required String product, required String status, String? failReason, required AtomicTransactCompany company, Map<
String, dynamic> ? switchData, Map<String, dynamic> ? depositData, Map<String, dynamic> ? managedBy}) -
AtomicTransactTaskStatusUpdate.fromJson(Map<
Object?, Object?> json) -
factory
Properties
- company → AtomicTransactCompany
-
final
-
depositData
→ Map<
String, dynamic> ? -
final
- failReason → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
managedBy
→ Map<
String, dynamic> ? -
final
- product → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
-
switchData
→ Map<
String, dynamic> ? -
final
- taskId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited