DeeplinkStep class abstract
Deeplink step options
- Implementers
Constructors
- DeeplinkStep()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- step → AtomicDeeplinkStep
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
loginCompany(
{required String companyId, String? connectorId, bool? singleSwitch}) → DeeplinkStepLoginCompany - Deeplink to the company login step
-
loginPayroll(
{required String connectorId, required String companyName}) → DeeplinkStepLoginPayroll - Deeplink to the payroll login step
Constants
- addCard → const DeeplinkStep
- Deeplink to the add card step
- searchCompany → const DeeplinkStep
- Deeplink to the company search step
- searchPayroll → const DeeplinkStep
- Deeplink to the payroll search step