AtomicMethodChannel class

Inheritance

Constructors

AtomicMethodChannel()

Properties

channel → MethodChannel
no setter
hashCode → int
The hash code for this object.
no setterinherited
onAuthStatusUpdate ↔ AtomicAuthStatusUpdateHandler?
Closure that will be called when a Transact auth status update event occurs
getter/setter pairinherited
onCompletion ↔ AtomicCompletionHandler?
Response with more information when Transact completes and dismisses.
getter/setter pairinherited
onDataRequest ↔ AtomicDataRequestHandler?
Closure that will be called when a Transact data request event occurs
getter/setter pairinherited
onInteraction ↔ AtomicInteractionHandler?
Closure that will be called when a Transact Interaction event occurs
getter/setter pairinherited
onLaunch ↔ AtomicLaunchHandler?
Closure that will be called when a Transact launch event occurs
getter/setter pairinherited
onTaskStatusUpdate ↔ AtomicTaskStatusUpdateHandler?
Closure that will be called when a Transact task status update event occurs
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dismissTransact() → Future<void>
override
hideTransact() → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseTransact() → Future<void>
override
presentTransact({required AtomicConfig configuration, required TransactEnvironment environment, AtomicPresentationStyleIOS? presentationStyleIOS, bool debug = false}) → Future<void>
Present the Atomic Transact SDK
override
resumeTransact() → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited