AtomicPlatformInterface class abstract

Inheritance
  • Object
  • PlatformInterface
  • AtomicPlatformInterface
Implementers

Constructors

AtomicPlatformInterface()

Properties

hashCode → int
The hash code for this object.
no setterinherited
onAuthStatusUpdate ↔ AtomicAuthStatusUpdateHandler?
Closure that will be called when a Transact auth status update event occurs
getter/setter pair
onCompletion ↔ AtomicCompletionHandler?
Response with more information when Transact completes and dismisses.
getter/setter pair
onDataRequest ↔ AtomicDataRequestHandler?
Closure that will be called when a Transact data request event occurs
getter/setter pair
onInteraction ↔ AtomicInteractionHandler?
Closure that will be called when a Transact Interaction event occurs
getter/setter pair
onLaunch ↔ AtomicLaunchHandler?
Closure that will be called when a Transact launch event occurs
getter/setter pair
onTaskStatusUpdate ↔ AtomicTaskStatusUpdateHandler?
Closure that will be called when a Transact task status update event occurs
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dismissTransact() → Future<void>
hideTransact() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseTransact() → Future<void>
presentTransact({required AtomicConfig configuration, required TransactEnvironment environment, AtomicPresentationStyleIOS? presentationStyleIOS, bool debug = false}) → Future<void>
Present the Atomic Transact SDK
resumeTransact() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ AtomicPlatformInterface
getter/setter pair